@@ -1,5 +1,5 @@
 """This library wraps the forked-daapd API for use with Home Assistant."""
-__version__ = "0.1.7"
+__version__ = "0.1.8"
 import asyncio
 import concurrent
 import logging
@@ -28,12 +28,6 @@ class ForkedDaapdAPI:
     async def test_connection(websession, host, port, password):
         """Validate the user input."""
 
-        def djb_hash(string):
-            hashed = 5381
-            for character in string:
-                hashed = ((hashed << 5) + hashed) + ord(character)
-            return hex(hashed & 0xFFFFFFFF)[2:].upper().rjust(8, "0")
-
         try:
             url = f"http://{host}:{port}/api/config"
             auth = (
@@ -49,7 +43,7 @@ class ForkedDaapdAPI:
                 # _LOGGER.debug("JSON %s", json)
                 if json["websocket_port"] == 0:
                     return ["websocket_not_enabled"]
-                return ["ok", djb_hash(json["library_name"])]
+                return ["ok", json["library_name"]]
         except (
             aiohttp.ClientConnectionError,
             asyncio.TimeoutError,
